Module args

Module args 

Command-line interface for git-lfs.

This module implements the command-line interface for git-lfs. It uses clap to parse command-line arguments. Commands are split out into subcommands, with one struct per subcommand.

This module is public so that other workspace tools can depend on it. Concretely, the man pages and markdown documentation are automatically generated from the command-line definitions.

Structs

CheckoutArgs
Populate working copy with real content from Git LFS files.
CleanArgs
Git clean filter that converts large files to pointers
Cli
Git LFS is a system for managing and versioning large files in association with a Git repository. Instead of storing the large files within the Git repository as blobs, Git LFS stores special “pointer files” in the repository, while storing the actual file contents on a Git LFS server. The contents of the large file are downloaded automatically when needed, for example when a Git branch containing the large file is checked out.
CloneArgs
Efficiently clone a LFS-enabled repository
EnvArgs
Display the Git LFS environment
ExtArgs
List the configured LFS pointer extensions
ExtListArgs
List configured LFS pointer extensions, optionally filtered by name.
FetchArgs
Download all Git LFS files for a given ref
FilterProcessArgs
Git filter process that converts between pointer and actual content
FsckArgs
Check Git LFS files for consistency
InstallArgs
Install Git LFS configuration
LockArgs
Set a file as “locked” on the Git LFS server
LocksArgs
Lists currently locked files from the Git LFS server
LogsArgs
Show errors logged by Git LFS
LsFilesArgs
Show information about Git LFS files in the index and working tree
MergeDriverArgs
Merge driver for LFS-tracked files
MigrateArgs
Migrate history to or from Git LFS
MigrateExportArgs
Convert Git LFS pointers to Git objects
MigrateImportArgs
Convert Git objects to Git LFS pointers
MigrateInfoArgs
Show information about repository size
PointerArgs
Build, compare, and check pointers
PostCheckoutArgs
Git post-checkout hook implementation
PostCommitArgs
Git post-commit hook implementation
PostMergeArgs
Git post-merge hook implementation
PrePushArgs
Git pre-push hook implementation
PruneArgs
Delete old LFS files from local storage
PullArgs
Download all Git LFS files for current ref and checkout
PushArgs
Push queued large files to the Git LFS endpoint
SmudgeArgs
Git smudge filter that converts pointer in blobs to the actual content
StatusArgs
Show the status of Git LFS files in the working tree
TrackArgs
View or add Git LFS paths to Git attributes
UninstallArgs
Remove Git LFS configuration
UnlockArgs
Remove “locked” setting for a file on the Git LFS server
UntrackArgs
Remove Git LFS paths from Git attributes
UpdateArgs
Update Git hooks
VersionArgs
Print the git-lfs version banner and exit

Enums

Command
ExtCmd
LogsSub
MigrateCmd