CleanArgs

Struct CleanArgs 

pub struct CleanArgs {
    pub path: Option<PathBuf>,
}
Git clean filter that converts large files to pointers

Read the contents of a large file from standard input, and write a Git LFS pointer file for that file to standard output.

Clean is typically run by Git’s clean filter, configured by the repository’s Git attributes.

Clean is not part of the user-facing Git plumbing commands. To preview the pointer of a large file as it would be generated, see the git-lfs-pointer(1) command.

Fields

path: Option<PathBuf>

Working-tree path of the file being cleaned.

Substituted for %f in any configured lfs.extension.<name>.clean command.