FsckArgs

Struct FsckArgs 

pub struct FsckArgs {
    pub refspec: Option<String>,
    pub objects: bool,
    pub pointers: bool,
    pub dry_run: bool,
}
Check Git LFS files for consistency

Check all Git LFS files in the current HEAD for consistency. Corrupted files are moved to .git/lfs/bad.

A single committish may be given to inspect that commit instead of HEAD. The <a>..<b> range form from upstream is not yet supported — only a single ref is accepted. With no argument, HEAD is examined.

The default is to perform all checks. lfs.fetchexclude is also not yet honored on this command; objects whose paths match the exclude list will still be checked.

Fields

refspec: Option<String>

Ref to scan. Defaults to HEAD.

objects: bool

Check that each object in HEAD matches its expected hash and that each object exists on disk.

pointers: bool

Check that each pointer is canonical and that each file which should be stored as a Git LFS file is so stored.

dry_run: bool

Perform checks, but do not move any corrupted files to .git/lfs/bad.