pub struct PostCheckoutArgs {
pub args: Vec<String>,
}Expand description
Git post-checkout hook implementation
Respond to Git post-checkout events. Git invokes this hook with
<rev-before> <ref-after> <is-branch-checkout>. We make sure that
any files which are marked as lockable by git lfs track are
read-only in the working copy, if not currently locked by the
local user.
Fields
args: Vec<String>Positional arguments passed by git. Not normally invoked by hand.