pub struct PostCommitArgs {
pub args: Vec<String>,
}Expand description
Git post-commit hook implementation
Respond to Git post-commit events. Like git lfs post-merge, we
make sure that any files which are marked as lockable by
git lfs track are read-only in the working copy, if not
currently locked by the local user.
Upstream optimizes by only checking files changed in HEAD; we currently scan the full work tree on every commit. The result is the same, but slower on large repositories.
Fields
args: Vec<String>Positional arguments passed by git. Not normally invoked by hand.