pub struct PrePushArgs {
pub remote: String,
pub url: Option<String>,
pub dry_run: bool,
}Expand description
Git pre-push hook implementation
Respond to Git pre-push events. Reads the range of commits from
stdin in the form <local-ref> <local-sha1> <remote-ref> <remote-sha1>, takes the remote name and URL as arguments, and
uploads any Git LFS objects associated with those commits to the
Git LFS API.
When pushing a new branch, the list of Git objects considered is every object reachable from the new branch. When deleting a branch, no LFS objects are pushed.
Fields
remote: StringName of the remote being pushed to.
url: Option<String>URL of the remote (informational; we use the lfs.url
config).
dry_run: boolPrint the files that would be pushed, without actually pushing them.