StatusArgs

Struct StatusArgs 

pub struct StatusArgs {
    pub porcelain: bool,
    pub json: bool,
}
Show the status of Git LFS files in the working tree

Display paths of Git LFS objects that have not been pushed to the Git LFS server (large files that would be uploaded by git push), that have differences between the index file and the current HEAD commit (large files that would be committed by git commit), or that have differences between the working tree and the index file (files that could be staged with git add).

Must be run in a non-bare repository.

Fields

porcelain: bool

Give the output in an easy-to-parse format for scripts.

json: bool

Write Git LFS file status information as JSON to standard output if the command exits successfully.

Intended for interoperation with external tools. If --porcelain is also provided, that option takes precedence.