UnlockArgs

Struct UnlockArgs 

pub struct UnlockArgs {
    pub paths: Vec<String>,
    pub remote: Option<String>,
    pub force: bool,
    pub id: Option<String>,
    pub json: bool,
    pub refspec: Option<String>,
}
Remove “locked” setting for a file on the Git LFS server

Removes the given file path as “locked” on the Git LFS server. Files must exist and have a clean git status before they can be unlocked. The --force flag will skip these checks.

Fields

paths: Vec<String>

Paths to unlock. Upstream’s CLI accepts a single path; ours accepts multiple (additive extension). Mutually exclusive with --id.

remote: Option<String>

Specify the Git LFS server to use. Ignored if the lfs.url config key is set.

force: bool

Tell the server to remove the lock, even if it’s owned by another user.

id: Option<String>

Specify a lock by its ID instead of path. Mutually exclusive with the positional paths.

json: bool

Write lock info as JSON to standard output if the command exits successfully.

Intended for interoperation with external tools. If the command returns with a non-zero exit code, plain text messages are sent to standard error.

refspec: Option<String>

Refspec to send with the unlock request (extension over upstream).

Defaults to the current branch’s tracked upstream — same auto-resolution as git lfs lock.