UpdateArgs

Struct UpdateArgs 

pub struct UpdateArgs {
    pub force: bool,
    pub manual: bool,
}
Update Git hooks

Update the Git hooks used by Git LFS. Silently upgrades known hook contents. If you have your own custom hooks you may need to use one of the extended options below.

Fields

force: bool

Forcibly overwrite any existing hooks with git-lfs hooks.

Use this option if git lfs update fails because of existing hooks but you don’t care about their current contents.

manual: bool

Print instructions for manually updating your hooks to include git-lfs functionality.

Use this option if git lfs update fails because of existing hooks and you want to retain their functionality.