Command-line interface for git-lfs.
This module implements the command-line interface for
git-lfs. It uses clap to parse command-line arguments.
Commands are split out into subcommands, with one struct per
subcommand.
This module is public so that other workspace tools can depend on it. Concretely, the man pages and markdown documentation are automatically generated from the command-line definitions.
Structs
- Checkout
Args - Populate working copy with real content from Git LFS files.
- Clean
Args - Git clean filter that converts large files to pointers
- Cli
- Git LFS is a system for managing and versioning large files in association with a Git repository. Instead of storing the large files within the Git repository as blobs, Git LFS stores special “pointer files” in the repository, while storing the actual file contents on a Git LFS server. The contents of the large file are downloaded automatically when needed, for example when a Git branch containing the large file is checked out.
- Clone
Args - Efficiently clone a LFS-enabled repository
- EnvArgs
- Display the Git LFS environment
- ExtArgs
- List the configured LFS pointer extensions
- ExtList
Args - List configured LFS pointer extensions, optionally filtered by name.
- Fetch
Args - Download all Git LFS files for a given ref
- Filter
Process Args - Git filter process that converts between pointer and actual content
- Fsck
Args - Check Git LFS files for consistency
- Install
Args - Install Git LFS configuration
- Lock
Args - Set a file as “locked” on the Git LFS server
- Locks
Args - Lists currently locked files from the Git LFS server
- Logs
Args - Show errors logged by Git LFS
- LsFiles
Args - Show information about Git LFS files in the index and working tree
- Merge
Driver Args - Merge driver for LFS-tracked files
- Migrate
Args - Migrate history to or from Git LFS
- Migrate
Export Args - Convert Git LFS pointers to Git objects
- Migrate
Import Args - Convert Git objects to Git LFS pointers
- Migrate
Info Args - Show information about repository size
- Pointer
Args - Build, compare, and check pointers
- Post
Checkout Args - Git post-checkout hook implementation
- Post
Commit Args - Git post-commit hook implementation
- Post
Merge Args - Git post-merge hook implementation
- PrePush
Args - Git pre-push hook implementation
- Prune
Args - Delete old LFS files from local storage
- Pull
Args - Download all Git LFS files for current ref and checkout
- Push
Args - Push queued large files to the Git LFS endpoint
- Smudge
Args - Git smudge filter that converts pointer in blobs to the actual content
- Status
Args - Show the status of Git LFS files in the working tree
- Track
Args - View or add Git LFS paths to Git attributes
- Uninstall
Args - Remove Git LFS configuration
- Unlock
Args - Remove “locked” setting for a file on the Git LFS server
- Untrack
Args - Remove Git LFS paths from Git attributes
- Update
Args - Update Git hooks
- Version
Args - Print the git-lfs version banner and exit