pub struct LocksArgs {
pub remote: Option<String>,
pub id: Option<String>,
pub path: Option<String>,
pub local: bool,
pub verify: bool,
pub limit: Option<u32>,
pub json: bool,
pub refspec: Option<String>,
}Expand description
Lists currently locked files from the Git LFS server
Lists current locks from the Git LFS server. Without filters, all locks visible to the configured remote are returned.
Fields
remote: Option<String>Specify the Git LFS server to use. Ignored if the lfs.url
config key is set.
id: Option<String>Specify a lock by its ID. Returns a single result.
path: Option<String>Specify a lock by its path. Returns a single result.
local: boolList only our own locks which are cached locally. Skips a remote call.
Useful when offline or to confirm what git lfs lock recorded
locally. Combine with --path / --id / --limit to filter;
--verify is rejected.
verify: boolVerify the lock owner on the server and mark our own locks
with O.
Own locks are held by us and the corresponding files can be
updated for the next push. All other locks are held by someone
else. Contrary to --local, this also detects locks held by us
despite no local lock information being available (e.g. because
the file had been locked from a different clone) and detects
“broken” locks (e.g. someone else forcibly unlocked our files).
limit: Option<u32>Maximum number of results to return.
json: boolWrite lock info as JSON to standard output if the command exits successfully.
Intended for interoperation with external tools. If the command returns with a non-zero exit code, plain text messages are sent to standard error.
refspec: Option<String>Refspec to filter locks by (extension over upstream).
Defaults to the current branch’s tracked upstream — same
auto-resolution as git lfs lock.