pub struct LsFilesArgs {
pub refspec: Option<String>,
pub long: bool,
pub size: bool,
pub name_only: bool,
pub all: bool,
pub debug: bool,
pub deleted: bool,
pub json: bool,
}Expand description
Show information about Git LFS files in the index and working tree
Display paths of Git LFS files that are found in the tree at the given reference. If no reference is given, scan the currently checked-out branch.
An asterisk (*) after the OID indicates a full object, a minus
(-) indicates an LFS pointer.
Note: upstream’s --include / --exclude path filters aren’t
yet supported. The two-references form (git lfs ls-files <a> <b>,
to show files modified between two refs) is also not yet
supported.
Fields
refspec: Option<String>Ref to list. Defaults to HEAD.
long: boolShow the entire 64-character OID, instead of just the first 10.
size: boolShow the size of the LFS object in parentheses at the end of each line.
name_only: boolShow only the LFS-tracked file names.
all: boolInspect the full history of the repository, not the current HEAD (or other provided reference).
Includes previous versions of LFS objects that are no longer found in the current tree.
debug: boolShow as much information as possible about an LFS file.
Intended for manual inspection; the exact format may change at any time.
deleted: boolInclude LFS pointers reachable from history but no longer present in the current tree.
json: boolWrite Git LFS file information as JSON to standard output if the command exits successfully.
Intended for interoperation with external tools. If --debug
is also provided, that option takes precedence. If any of
--long, --size, or --name-only are provided, those
options will have no effect.