pub struct MigrateArgs {
pub cmd: MigrateCmd,
}Expand description
Migrate history to or from Git LFS
Convert files in a Git repository to or from Git LFS pointers, or
summarize Git file sizes by file type. The import mode converts
Git files (i.e. blobs) to Git LFS, the export mode does the
reverse, and the info mode provides an informational summary
useful for deciding which files to import or export.
In all modes, by default git lfs migrate operates only on the
currently checked-out branch, and only on files added in commits
which do not exist on any remote. Multiple options are available
to override these defaults — see INCLUDE AND EXCLUDE REFERENCES.
When converting files to or from Git LFS, this command only
changes your local repository and working copy, never any remotes.
import and export are generally DESTRUCTIVE — they rewrite Git
history, changing commits and generating new commit SHAs. (The
exception is the --no-rewrite import sub-mode.) Always commit
or stash any uncommitted work first, validate the result before
pushing, and force-push the new history once you’re satisfied.
For info and import, all file types are considered by default.
In import you’ll usually want filename patterns or --fixup;
export requires at least one --include pattern. See INCLUDE
AND EXCLUDE.
git lfs migrate will examine, create, and modify .gitattributes
files as necessary. They are always assigned the default
read/write permissions mode; symbolic links with that name halt
the migration.
Fields
cmd: MigrateCmdTrait Implementations
Sourceimpl Args for MigrateArgs
impl Args for MigrateArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for MigrateArgs
impl FromArgMatches for MigrateArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.