pub struct PointerArgs {
pub file: Option<PathBuf>,
pub pointer: Option<PathBuf>,
pub stdin: bool,
pub check: bool,
pub strict: bool,
pub no_strict: bool,
pub no_extensions: bool,
}Expand description
Build, compare, and check pointers
Build and optionally compare generated pointer files to ensure consistency between different Git LFS implementations.
Fields
file: Option<PathBuf>A local file to build the pointer from.
pointer: Option<PathBuf>A local file containing a pointer generated from another implementation.
Compared to the pointer generated from --file.
stdin: boolRead the pointer from standard input to compare with the
pointer generated from --file.
check: boolRead the pointer from standard input (with --stdin) or the
filepath (with --file).
If neither or both of --stdin and --file are given, the
invocation is invalid. Exits 0 if the data read is a valid Git
LFS pointer, 1 otherwise. With --strict, exits 2 if the
pointer is not byte-canonical.
strict: boolWith --check, verify that the pointer is canonical (the one
Git LFS would create).
If it isn’t, exits 2. The default — for backwards compatibility
— is --no-strict.
no_strict: boolDisable strict mode (paired with --strict).
no_extensions: boolBuild a plain pointer without running configured lfs.extension.*
clean commands. Default behavior is to chain through any
extensions (and emit a warning: line on stderr); pass this to
suppress both the chain and the warning.