pub struct UninstallArgs {
pub mode: Option<String>,
pub local: bool,
pub worktree: bool,
pub system: bool,
pub file: Option<PathBuf>,
pub skip_repo: bool,
}Expand description
Remove Git LFS configuration
Remove the lfs clean and smudge filters from the global Git config,
and (when run from inside a Git repository) uninstall the Git LFS
pre-push hook. Hooks that don’t match what we would write are left
untouched.
Fields
mode: Option<String>Optional mode. With hooks, removes only the LFS git hooks and
leaves the filter config alone (the inverse of --skip-repo).
local: boolRemove the lfs smudge and clean filters from the local
repository’s git config, instead of the global git config
(~/.gitconfig).
worktree: boolRemove the lfs smudge and clean filters from the current
working tree’s git config, instead of the global git config
(~/.gitconfig) or local repository’s git config
($GIT_DIR/config).
If multiple working trees are in use, the Git config extension
worktreeConfig must be enabled to use this option. If only one
working tree is in use, --worktree has the same effect as
--local. Available only on Git v2.20.0 or later.
system: boolRemove the lfs smudge and clean filters from the system git
config, instead of the global git config (~/.gitconfig).
file: Option<PathBuf>Remove the lfs smudge and clean filters from the Git
configuration file specified by <PATH>.
skip_repo: boolSkip cleanup of the local repo.
Use if you want to uninstall the global LFS filters but not make changes to the current repo.